AppLocalizations class

Constructors

AppLocalizations()

Properties

athmExceptionMessage String
Sorry for the inconvenience. Please try again later.
no setter
athmExceptionTitle String
Something went wrong...
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current AppLocalizations
no setter

Static Methods

load(Locale locale) Future<AppLocalizations>
maybeOf(BuildContext context) AppLocalizations?
of(BuildContext context) AppLocalizations

Constants

delegate → const AppLocalizationDelegate