ConstantsUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ATH_PAYMENT_VALIDATION_FAILED → const String
- ATHM_ASSETS → const String
- ASSETS
- ATHM_BLACK_COLOR → const Color
- ATHM_BUSINESS_TOKEN_MESSAGE → const String
- ATHM_CANCELLED → const String
- ATHM_CANCELLED_iOS_RESULT → const String
- ATHM_CANCELLED_RESULT → const String
- ATHM_COMPLETED → const String
- ATHM_DARK_COLOR → const Color
- THEME COLORS
- ATHM_DARK_THEME → const String
- ATHM_DECODE_JSON_ERROR_MESSAGE → const String
- ATHM_DEFAULT → const String
- ATHM_DEFAULT_COLOR → const Color
- ATHM_DEFAULT_THEME → const String
- THEME STYLES
- ATHM_ENCODE_JSON_ERROR_MESSAGE → const String
- ATHM_EXCEPTION → const String
- ATHM_EXCEPTION_MESSAGE → const String
- ATHM_EXCEPTION_TITLE → const String
- ATHM_EXPIRED → const String
- ATHM_EXPIRED_iOS_RESULT → const String
- ATHM_EXPIRED_RESULT → const String
- ATHM_FAILED → const String
- ATHM_FAILED_iOS_RESULT → const String
- ATHM_FAILED_RESULT → const String
- ERROR MESSAGES
- ATHM_ITEM_DESC_ERROR_MESSAGE → const String
- ATHM_ITEM_NAME_ERROR_MESSAGE → const String
- ATHM_ITEM_QUANTITY_ERROR_MESSAGE → const String
- ATHM_ITEM_TOTAL_ERROR_MESSAGE → const String
- ATHM_LIGHT_COLOR → const Color
- ATHM_LIGHT_THEME → const String
- ATHM_MAX_TIMEOUT → const int
- ATHM_METADATA1_ERROR_MESSAGE → const String
- ATHM_METADATA2_ERROR_MESSAGE → const String
- ATHM_MIN_TIMEOUT → const int
- ATHM_NULL_ITEM_METADATA_ERROR_MESSAGE → const String
- ATHM_NULL_METADATA_ERROR_MESSAGE → const String
- ATHM_NULL_PUBLICTOKEN_ERROR_MESSAGE → const String
- ATHM_PACKAGE_NAME → const String
- ATHM_PAYMENT_ERROR_MESSAGE → const String
- ATHM_PAYMENT_VALIDATION_FAILED → const String
- ATHM_REQUEST_EXCEPTION_TITLE → const String
- ATHM_RESPONSE_EXCEPTION_TITLE → const String
- ATHM_SCHEMA_ERROR_MESSAGE → const String
- ATHM_SUBTOTAL_ERROR_MESSAGE → const String
- ATHM_TAX_NULL_ERROR_MESSAGE → const String
- ATHM_TOTAL_ERROR_MESSAGE → const String
- ATHM_TXT_BTN_BLACK → const String
- ATHM_TXT_BTN_BLACK_ES → const String
- ATHM_TXT_BTN_WHITE → const String
- ATHM_TXT_BTN_WHITE_ES → const String
- ATHM_WHITE_COLOR → const Color