ATHMovilValidationUtil class

Constructors

ATHMovilValidationUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setTimeout(int? timeout) int
validatePurchaseDataDouble(double? doubleString, double minValue) bool
validatePurchaseDataString(String? dataString) bool
validatePurchaseItemsData(ATHMovilPayment request) bool
validateRequest(ATHMovilPayment athMovilPayment) ATHMovilException?