AthmovilCheckoutFlutter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decodeResponseTest(
String payment) → ATHMovilPaymentResponse? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setListener(
ATHMovilPaymentResponseListener listener) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validateResponse(
String response, ATHMovilPaymentResponseListener listener) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
platformVersion
→ Future<
String?> -
no setter
Static Methods
-
callHandler(
MethodCall methodCall) → Future -
decodeResponse(
String payment) → ATHMovilPaymentResponse? -
encodeRequest(
ATHMovilPayment payment) → String -
openATHMovil(
{ATHMovilPayment? athMovilPayment, String? buildType, ATHMovilPaymentResponseListener? athMovilPaymentResponseListener}) → Future< bool> -
sendPayment(
{ATHMovilPayment? athMovilPayment, String? buildType, ATHMovilPaymentResponseListener? athMovilPaymentResponseListener}) → Future< bool>
Constants
- CHANNEL_NAME → const String