Utils class
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPrefsBool(
{required String key}) → Future< bool?> -
getPrefsDouble(
{required String key}) → Future< double?> -
getPrefsInt(
{required String key}) → Future< int?> -
getPrefsString(
{required String key}) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setPrefsBool(
{required String key, required bool value}) → Future< bool> -
setPrefsDouble(
{required String key, required double value}) → Future< bool> -
setPrefsInt(
{required String key, required int value}) → Future< bool> -
setPrefsString(
{required String key, required String value}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited